==> google-cloud-domains-0.2.1.tar.gz: google-cloud-domains-0.2.1/google/cloud/domains_v1beta1/types/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .domains import (
    AuthorizationCode,
    ConfigureContactSettingsRequest,
    ConfigureDnsSettingsRequest,
    ConfigureManagementSettingsRequest,
    ContactSettings,
    DeleteRegistrationRequest,
    DnsSettings,
    ExportRegistrationRequest,
    GetRegistrationRequest,
    ListRegistrationsRequest,
    ListRegistrationsResponse,
    ManagementSettings,
    OperationMetadata,
    RegisterDomainRequest,
    RegisterParameters,
    Registration,
    ResetAuthorizationCodeRequest,
    RetrieveAuthorizationCodeRequest,
    RetrieveRegisterParametersRequest,
    RetrieveRegisterParametersResponse,
    SearchDomainsRequest,
    SearchDomainsResponse,
    UpdateRegistrationRequest,
    ContactNotice,
    ContactPrivacy,
    DomainNotice,
    TransferLockState,
)

__all__ = (
    "AuthorizationCode",
    "ConfigureContactSettingsRequest",
    "ConfigureDnsSettingsRequest",
    "ConfigureManagementSettingsRequest",
    "ContactSettings",
    "DeleteRegistrationRequest",
    "DnsSettings",
    "ExportRegistrationRequest",
    "GetRegistrationRequest",
    "ListRegistrationsRequest",
    "ListRegistrationsResponse",
    "ManagementSettings",
    "OperationMetadata",
    "RegisterDomainRequest",
    "RegisterParameters",
    "Registration",
    "ResetAuthorizationCodeRequest",
    "RetrieveAuthorizationCodeRequest",
    "RetrieveRegisterParametersRequest",
    "RetrieveRegisterParametersResponse",
    "SearchDomainsRequest",
    "SearchDomainsResponse",
    "UpdateRegistrationRequest",
    "ContactNotice",
    "ContactPrivacy",
    "DomainNotice",
    "TransferLockState",
)

==> google-cloud-domains-1.1.1.tar.gz: google-cloud-domains-1.1.1/google/cloud/domains_v1beta1/types/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .domains import (
    AuthorizationCode,
    ConfigureContactSettingsRequest,
    ConfigureDnsSettingsRequest,
    ConfigureManagementSettingsRequest,
    ContactSettings,
    DeleteRegistrationRequest,
    DnsSettings,
    ExportRegistrationRequest,
    GetRegistrationRequest,
    ListRegistrationsRequest,
    ListRegistrationsResponse,
    ManagementSettings,
    OperationMetadata,
    RegisterDomainRequest,
    RegisterParameters,
    Registration,
    ResetAuthorizationCodeRequest,
    RetrieveAuthorizationCodeRequest,
    RetrieveRegisterParametersRequest,
    RetrieveRegisterParametersResponse,
    RetrieveTransferParametersRequest,
    RetrieveTransferParametersResponse,
    SearchDomainsRequest,
    SearchDomainsResponse,
    TransferDomainRequest,
    TransferParameters,
    UpdateRegistrationRequest,
    ContactNotice,
    ContactPrivacy,
    DomainNotice,
    TransferLockState,
)

__all__ = (
    "AuthorizationCode",
    "ConfigureContactSettingsRequest",
    "ConfigureDnsSettingsRequest",
    "ConfigureManagementSettingsRequest",
    "ContactSettings",
    "DeleteRegistrationRequest",
    "DnsSettings",
    "ExportRegistrationRequest",
    "GetRegistrationRequest",
    "ListRegistrationsRequest",
    "ListRegistrationsResponse",
    "ManagementSettings",
    "OperationMetadata",
    "RegisterDomainRequest",
    "RegisterParameters",
    "Registration",
    "ResetAuthorizationCodeRequest",
    "RetrieveAuthorizationCodeRequest",
    "RetrieveRegisterParametersRequest",
    "RetrieveRegisterParametersResponse",
    "RetrieveTransferParametersRequest",
    "RetrieveTransferParametersResponse",
    "SearchDomainsRequest",
    "SearchDomainsResponse",
    "TransferDomainRequest",
    "TransferParameters",
    "UpdateRegistrationRequest",
    "ContactNotice",
    "ContactPrivacy",
    "DomainNotice",
    "TransferLockState",
)
